@@ -2,6 +2,18 @@
 
 #ifdef USE_HILDON
 #include <libosso.h>
+void
+on_toolStackableWindow (void);
+
+void
+hildon_share_tool			(GtkMenuItem  *menuitem,
+                                         gpointer      user_data);
+
+void
+hildon_tools_radio_action		(GtkAction *action);
+
+void
+hildon_tools_other_action		(GtkAction *action);
 
 void
 on_HildonHelp_activate			(GtkWidget *widget,
@@ -432,6 +444,10 @@ on_canvas_enter_notify_event           (GtkWidget       *widget,
                                         gpointer         user_data);
 
 gboolean
+on_canvas_leave_notify_event           (GtkWidget       *widget,
+                                        GdkEventCrossing *event,
+                                        gpointer         user_data);
+gboolean
 on_canvas_expose_event                 (GtkWidget       *widget,
                                         GdkEventExpose  *event,
                                         gpointer         user_data);
@@ -499,10 +515,6 @@ void
 on_optionsButtonMappings_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_optionsAntialiasBG_activate         (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_optionsProgressiveBG_activate       (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -626,9 +638,8 @@ on_optionsPrintRuling_activate         (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
-on_optionsDiscardCore_activate         (GtkMenuItem     *menuitem,
+on_optionsAutoloadPdfXoj_activate      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
-
 void
 on_fontButton_font_set                 (GtkFontButton   *fontbutton,
                                         gpointer         user_data);
@@ -652,3 +663,11 @@ on_toolsReco_activate                  (GtkMenuItem     *menuitem,
 void
 on_optionsPressureSensitive_activate   (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+
+void
+on_buttonColorChooser_set              (GtkColorButton  *colorbutton,
+                                        gpointer         user_data);
+
+void
+on_optionsButtonsSwitchMappings_activate(GtkMenuItem    *menuitem,
+                                        gpointer         user_data);
